@@ -1,12 +1,10 @@
-# Rdsm test, Test1.R: test barrier, basic shared vector, matrix ops
+# test barrier, basic shared vector, matrix ops
+
+# simply call test()
 
 test <- function() {
    me <- myinfo$myid
-   if(me == 1) {
-      newdsm("y","dsmv",val=c(5,12,13),thismode="integer")
-      message("use lock variables to avoid intermixing output")
-   } else
-      newdsm("y","dsmv",size=3,thismode="integer")
+   cnewdsm("y","dsmv",thismode="integer",val=c(5,12,13))
    barr()
    message("should print 5 12 13")
    message(cat(y[]))  
@@ -26,19 +24,13 @@ test <- function() {
    message("should print 10 20 50")
    message(cat(y[]))  
    barr()
-   if(me == 1) {
-      newdsm("z","dsmv",val=8,thismode="integer")
-   } else
-      newdsm("z","dsmv",size=1,thismode="integer")
+   cnewdsm("z","dsmv",thismode="integer",val=8)
    barr()
    z[1] <- 20
    message("should print 20")
    message(z[1])  
    barr()
-   if(me == 1) {
-      newdsm("m","dsmm",val=rbind(1:3,4:6),thismode="integer")
-   } else
-      newdsm("m","dsmm",size=c(2,3),thismode="integer")
+   cnewdsm("m","dsmm",thismode="integer",val=rbind(1:3,4:6))
    barr()
    message("should print matrix with rows 1,2,3 and 4,5,6")
    message(cat(m[1,]))  
@@ -52,10 +44,7 @@ test <- function() {
    barr()
    message("should print matrix with rows 2,3 and 5,6")
    xval <- m[1:2,2:3]
-   if(me == 1) {
-      newdsm("x","dsmm",val=xval,thismode="integer")
-   } else
-      newdsm("x","dsmm",size=c(2,2),thismode="integer")
+   cnewdsm("x","dsmm",thismode="integer",val=xval)
    message(cat(x[1,]))  
    message(cat(x[2,]))  
    barr()
@@ -64,5 +53,4 @@ test <- function() {
    x[,] <- m[1:2,2:3]
    message(cat(x[1,]))  
    message(cat(x[2,]))  
-   dsmexit()
 }
