@@ -1,13 +1,13 @@
 # test locks
 
+# run with any number of clients
+
+# should output 1.2 times n times number of clients
+
 test <- function(n) {
    me <- myinfo$myid
    message("I am ",me)
-   if (me == 1) {
-      newdsm("y","dsmv","double",val=0)
-   } else {
-      newdsm("y","dsmv","double",size=1)
-   }
+   cnewdsm("y","dsmv","double",0)
    barr()
    for (i in 1:n) {
       # make arrival time to lock random, so as to test different
@@ -25,9 +25,4 @@ test <- function(n) {
    message("from ",me,": y = ",y[1])
    unlock("msglk")
    barr()
-   dsmexit()
 }
-
-# run with any number of clients
-
-# should output 1.2 times n times number of clients
