@@ -1,12 +1,12 @@
 # test fetch-and-add
 
+# run with any number of clients
+
+# should get output of number of clients times n(n+1)/2
+
 test <- function(n) {
    me <- myinfo$myid
-   if(me == 1) {
-      newdsm("y","dsmv","integer",val=0)
-   } else {
-      newdsm("y","dsmv","integer",size=1)
-   }
+   cnewdsm("y","dsmv","integer",0)
    barr()
    for (i in 1:n) {
       message(me,":  y = ",y[])
@@ -17,9 +17,4 @@ test <- function(n) {
    lock("msglk")
    message("from ",me,": y = ",y[])
    unlock("msglk")
-   dsmexit()
 }
-
-# run with any number of clients
-
-# should get output of 15 times number of clients
